@@ -13,7 +13,6 @@
 #include <QDir>
 #include <QFile>
 #include <QProcess>
-#include <QSharedPointer>
 #include <qstandardpaths.h>
 #include <qtemporaryfile.h>
 
@@ -486,3 +485,5 @@ void TestKConfUpdate::testScript()
     expectedNewConfContent = expectedNewConfContent.arg(updateInfo);
     QCOMPARE(newConfContent, expectedNewConfContent);
 }
+
+#include "moc_test_kconf_update.cpp"
