@@ -16,7 +16,7 @@
 #include <QHash>
 #include <QStringList>
 
-#include "kconfigdata.h"
+#include "kconfigdata_p.h"
 #include "kconfigini_p.h"
 
 typedef QExplicitlySharedDataPointer<KConfigBackend> BackendPtr;
@@ -86,3 +86,5 @@ void KConfigBackend::setLocalFilePath(const QString &file)
 {
     d->localFileName = file;
 }
+
+#include "moc_kconfigbackend_p.cpp"
