@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2018 David Edmundson <davidedmundson@kde.org>
+    SPDX-FileCopyrightText: 2023 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,6 +14,8 @@
 #include <QDBusConnection>
 #include <QDBusMessage>
 #include <QDBusMetaType>
+
+#include "dbussanitizer_p.h"
 #endif
 
 #include <QDebug>
@@ -49,24 +52,34 @@ KConfigWatcher::KConfigWatcher(const KSharedConfig::Ptr &config)
     , d(new KConfigWatcherPrivate)
 {
     Q_ASSERT(config);
+    d->m_config = config;
+
 #if KCONFIG_USE_DBUS
+    if (config->name().isEmpty()) {
+        return;
+    }
+
+    // Watching absolute paths is not supported and also makes no sense.
+    const bool isAbsolutePath = config->name().at(0) == QLatin1Char('/');
+    if (isAbsolutePath) {
+        qCWarning(KCONFIG_CORE_LOG) << "Watching absolute paths is not supported" << config->name();
+        return;
+    }
 
     qDBusRegisterMetaType<QByteArrayList>();
     qDBusRegisterMetaType<QHash<QString, QByteArrayList>>();
 
-    d->m_config = config;
-
-    QStringList watchedPaths;
-    watchedPaths << QLatin1Char('/') + d->m_config->name();
-    const auto cfgSources = d->m_config->additionalConfigSources();
-    for (const QString &file : cfgSources) {
-        watchedPaths << QLatin1Char('/') + file;
+    QStringList watchedPaths = d->m_config->additionalConfigSources();
+    for (QString &file : watchedPaths) {
+        file.prepend(QLatin1Char('/'));
     }
+    watchedPaths.prepend(kconfigDBusSanitizePath(QLatin1Char('/') + d->m_config->name()));
+
     if (d->m_config->openFlags() & KConfig::IncludeGlobals) {
         watchedPaths << QStringLiteral("/kdeglobals");
     }
 
-    for (const QString &path : qAsConst(watchedPaths)) {
+    for (const QString &path : std::as_const(watchedPaths)) {
         QDBusConnection::sessionBus().connect(QString(),
                                               path,
                                               QStringLiteral("org.kde.kconfig.notify"),
@@ -101,3 +114,5 @@ void KConfigWatcher::onConfigChangeNotification(const QHash<QString, QByteArrayL
         Q_EMIT configChanged(group, it.value());
     }
 }
+
+#include "moc_kconfigwatcher.cpp"
