@@ -54,9 +54,9 @@ public:
     /**
      * Destructs the KDesktopFile object.
      *
-     * Writes back any dirty configuration entries.
+     * Writes back any changed configuration entries.
      */
-    virtual ~KDesktopFile();
+    ~KDesktopFile() override;
 
     /**
      * Checks whether this is really a desktop file.
@@ -91,6 +91,9 @@ public:
      */
     static QString locateLocal(const QString &path);
 
+    /**
+     * Returns the main config group (named "Desktop Entry") in a .desktop file.
+     */
     KConfigGroup desktopGroup() const;
 
     /**
@@ -129,11 +132,16 @@ public:
      */
     QString readPath() const;
 
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 82)
     /**
      * Returns the value of the "Dev=" entry.
      * @return the device or QString() if not specified
+     * @deprecated since 5.82, for lack of usage, the FSDevice .desktop template
+     * hadn't been installed for a long time.
      */
+    KCONFIGCORE_DEPRECATED_VERSION(5, 82, "For lack of usage.")
     QString readDevice() const;
+#endif
 
     /**
      * Returns the value of the "URL=" entry.
@@ -160,6 +168,7 @@ public:
      */
     KConfigGroup actionGroup(const QString &group);
 
+    // TODO KF6, don't return by const value
     const KConfigGroup actionGroup(const QString &group) const;
 
     /**
@@ -233,15 +242,19 @@ public:
      */
     KDesktopFile *copyTo(const QString &file) const;
 
+    /**
+     * Returns the name of the .desktop file that was used to construct this KDesktopFile.
+     */
     QString fileName() const;
 
+#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 89)
+    /**
+     * @deprecated Since 5.89, use locationType() instead.
+     */
+    KCONFIGCORE_DEPRECATED_VERSION(5, 89, "Use locationType() instead.")
     QStandardPaths::StandardLocation resource() const;
+#endif
 
-protected:
-    /** Virtual hook, used to add new "virtual" functions while maintaining
-        binary compatibility. Unused in this class.
-    */
-    //  virtual void virtual_hook( int id, void* data );
 private:
     Q_DISABLE_COPY(KDesktopFile)
 
