@@ -9,15 +9,15 @@
 #ifndef KCONFIGUTILS_H
 #define KCONFIGUTILS_H
 
+#include <QStringList>
+
 class QString;
-class QStringList;
 
 class KConfig;
 class KConfigGroup;
 
 namespace KConfigUtils
 {
-
 bool hasGroup(KConfig *, const QStringList &);
 
 KConfigGroup openGroup(KConfig *, const QStringList &);
