@@ -1,50 +1,35 @@
 /*
     This file is part of KDE.
 
-    Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>
-    Copyright (c) 2003 Waldo Bastian <bastian@kde.org>
-    Copyright (c) 2003 Zack Rusin <zack@kde.org>
-    Copyright (c) 2006 Michaël Larouche <michael.larouche@kdemail.net>
-    Copyright (c) 2008 Allen Winter <winter@kde.org>
+    SPDX-FileCopyrightText: 2003 Cornelius Schumacher <schumacher@kde.org>
+    SPDX-FileCopyrightText: 2003 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2003 Zack Rusin <zack@kde.org>
+    SPDX-FileCopyrightText: 2006 Michaël Larouche <michael.larouche@kdemail.net>
+    SPDX-FileCopyrightText: 2008 Allen Winter <winter@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-// Compiling this file with this flag is just crazy
-#undef QT_NO_CAST_FROM_ASCII
-
+#include <QCommandLineOption>
+#include <QCommandLineParser>
 #include <QCoreApplication>
+#include <QDomAttr>
 #include <QFile>
 #include <QFileInfo>
-#include <QSettings>
-#include <QTextStream>
-#include <QDomAttr>
 #include <QRegularExpression>
+#include <QSettings>
 #include <QStringList>
-#include <QCommandLineParser>
-#include <QCommandLineOption>
+#include <QTextStream>
 
-#include <ostream>
+#include <algorithm>
 #include <iostream>
+#include <ostream>
 #include <stdlib.h>
 
 #include "../../kconfig_version.h"
-#include "KConfigParameters.h"
 #include "KConfigCommonStructs.h"
 #include "KConfigHeaderGenerator.h"
+#include "KConfigParameters.h"
 #include "KConfigSourceGenerator.h"
 #include "KConfigXmlParser.h"
 
@@ -53,10 +38,10 @@ QString varName(const QString &n, const KConfigParameters &cfg)
     QString result;
     if (!cfg.dpointer) {
         result = QChar::fromLatin1('m') + n;
-        result[1] = result[1].toUpper();
+        result[1] = result.at(1).toUpper();
     } else {
         result = n;
-        result[0] = result[0].toLower();
+        result[0] = result.at(0).toLower();
     }
     return result;
 }
@@ -65,7 +50,7 @@ QString varPath(const QString &n, const KConfigParameters &cfg)
 {
     QString result;
     if (cfg.dpointer) {
-        result = "d->" + varName(n, cfg);
+        result = QLatin1String{"d->"} + varName(n, cfg);
     } else {
         result = varName(n, cfg);
     }
@@ -75,7 +60,7 @@ QString varPath(const QString &n, const KConfigParameters &cfg)
 QString enumName(const QString &n)
 {
     QString result = QLatin1String("Enum") + n;
-    result[4] = result[4].toUpper();
+    result[4] = result.at(4).toUpper();
     return result;
 }
 
@@ -84,7 +69,7 @@ QString enumName(const QString &n, const CfgEntry::Choices &c)
     QString result = c.name();
     if (result.isEmpty()) {
         result = QLatin1String("Enum") + n;
-        result[4] = result[4].toUpper();
+        result[4] = result.at(4).toUpper();
     }
     return result;
 }
@@ -97,7 +82,7 @@ QString enumType(const CfgEntry *e, bool globalEnums)
         if (!globalEnums) {
             result += QLatin1String("::type");
         }
-        result[4] = result[4].toUpper();
+        result[4] = result.at(4).toUpper();
     }
     return result;
 }
@@ -107,7 +92,7 @@ QString enumTypeQualifier(const QString &n, const CfgEntry::Choices &c)
     QString result = c.name();
     if (result.isEmpty()) {
         result = QLatin1String("Enum") + n + QLatin1String("::");
-        result[4] = result[4].toUpper();
+        result[4] = result.at(4).toUpper();
     } else if (c.external()) {
         result = c.externalQualifier();
     } else {
@@ -119,7 +104,7 @@ QString enumTypeQualifier(const QString &n, const CfgEntry::Choices &c)
 QString setFunction(const QString &n, const QString &className)
 {
     QString result = QLatin1String("set") + n;
-    result[3] = result[3].toUpper();
+    result[3] = result.at(3).toUpper();
 
     if (!className.isEmpty()) {
         result = className + QLatin1String("::") + result;
@@ -129,16 +114,16 @@ QString setFunction(const QString &n, const QString &className)
 
 QString changeSignalName(const QString &n)
 {
-    return n+QStringLiteral("Changed");
+    return n + QLatin1String{"Changed"};
 }
 
 QString getDefaultFunction(const QString &n, const QString &className)
 {
-    QString result = QLatin1String("default") +  n + QLatin1String("Value");
-    result[7] = result[7].toUpper();
+    QString result = QLatin1String("default%1Value").arg(n);
+    result[7] = result.at(7).toUpper();
 
     if (!className.isEmpty()) {
-        result = className + QLatin1String("::") + result;
+        result.prepend(className + QLatin1String("::"));
     }
     return result;
 }
@@ -146,10 +131,10 @@ QString getDefaultFunction(const QString &n, const QString &className)
 QString getFunction(const QString &n, const QString &className)
 {
     QString result = n;
-    result[0] = result[0].toLower();
+    result[0] = result.at(0).toLower();
 
     if (!className.isEmpty()) {
-        result = className + QLatin1String("::") + result;
+        result.prepend(className + QLatin1String("::"));
     }
     return result;
 }
@@ -157,11 +142,11 @@ QString getFunction(const QString &n, const QString &className)
 QString immutableFunction(const QString &n, const QString &className)
 {
     QString result = QLatin1String("is") + n;
-    result[2] = result[2].toUpper();
-    result += "Immutable";
+    result[2] = result.at(2).toUpper();
+    result += QLatin1String{"Immutable"};
 
     if (!className.isEmpty()) {
-        result = className + QLatin1String("::") + result;
+        result.prepend(className + QLatin1String("::"));
     }
     return result;
 }
@@ -186,41 +171,31 @@ static QString quoteString(const QString &s)
     return QLatin1Char('\"') + r + QLatin1Char('\"');
 }
 
-QString literalString(const QString &s)
+QString literalString(const QString &str)
 {
-    bool isAscii = true;
-    for (int i = s.length(); i--;)
-        if (s[i].unicode() > 127) {
-            isAscii = false;
-        }
+    const bool isAscii = std::none_of(str.cbegin(), str.cend(), [](const QChar ch) {
+        return ch.unicode() > 127;
+    });
 
     if (isAscii) {
-        return QLatin1String("QStringLiteral( ") + quoteString(s) + QLatin1String(" )");
+        return QLatin1String("QStringLiteral( %1 )").arg(quoteString(str));
     } else {
-        return QLatin1String("QString::fromUtf8( ") + quoteString(s) + QLatin1String(" )");
+        return QLatin1String("QString::fromUtf8( %1 )").arg(quoteString(str));
     }
 }
 
-
 QString signalEnumName(const QString &signalName)
 {
     QString result;
     result = QLatin1String("signal") + signalName;
-    result[6] = result[6].toUpper();
+    result[6] = result.at(6).toUpper();
 
     return result;
 }
 
-
 bool isUnsigned(const QString &type)
 {
-    if (type == QLatin1String("UInt")) {
-        return true;
-    }
-    if (type == QLatin1String("ULongLong")) {
-        return true;
-    }
-    return false;
+    return type == QLatin1String("UInt") || type == QLatin1String("ULongLong");
 }
 
 /**
@@ -273,7 +248,7 @@ QString param(const QString &t)
         return QStringLiteral("const QList<QUrl> &");
     } else {
         std::cerr << "kconfig_compiler_kf5 does not support type \"" << qPrintable(type) << "\"" << std::endl;
-        return QStringLiteral("QString"); //For now, but an assert would be better
+        return QStringLiteral("QString"); // For now, but an assert would be better
     }
 }
 
@@ -327,7 +302,7 @@ QString cppType(const QString &t)
         return QStringLiteral("QList<QUrl>");
     } else {
         std::cerr << "kconfig_compiler_kf5 does not support type \"" << qPrintable(type) << "\"" << std::endl;
-        return QStringLiteral("QString"); //For now, but an assert would be better
+        return QStringLiteral("QString"); // For now, but an assert would be better
     }
 }
 
@@ -335,7 +310,7 @@ QString defaultValue(const QString &t)
 {
     const QString type = t.toLower();
     if (type == QLatin1String("string")) {
-        return QStringLiteral("\"\"");    // Use empty string, not null string!
+        return QStringLiteral("\"\""); // Use empty string, not null string!
     } else if (type == QLatin1String("stringlist")) {
         return QStringLiteral("QStringList()");
     } else if (type == QLatin1String("font")) {
@@ -367,47 +342,53 @@ QString defaultValue(const QString &t)
     } else if (type == QLatin1String("enum")) {
         return QStringLiteral("0");
     } else if (type == QLatin1String("path")) {
-        return QStringLiteral("\"\"");    // Use empty string, not null string!
+        return QStringLiteral("\"\""); // Use empty string, not null string!
     } else if (type == QLatin1String("pathlist")) {
         return QStringLiteral("QStringList()");
     } else if (type == QLatin1String("password")) {
-        return QStringLiteral("\"\"");    // Use empty string, not null string!
+        return QStringLiteral("\"\""); // Use empty string, not null string!
     } else if (type == QLatin1String("url")) {
         return QStringLiteral("QUrl()");
     } else if (type == QLatin1String("urllist")) {
         return QStringLiteral("QList<QUrl>()");
     } else {
         std::cerr << "Error, kconfig_compiler_kf5 does not support the \"" << qPrintable(type) << "\" type!" << std::endl;
-        return QStringLiteral("QString"); //For now, but an assert would be better
+        return QStringLiteral("QString"); // For now, but an assert would be better
     }
 }
 
 QString itemType(const QString &type)
 {
-    QString t;
+    if (type.isEmpty()) {
+        return QString{};
+    }
 
-    t = type;
-    t.replace(0, 1, t.left(1).toUpper());
+    QString str = type;
+    str[0] = str.at(0).toUpper();
 
-    return t;
+    return str;
 }
 
 QString itemDeclaration(const CfgEntry *e, const KConfigParameters &cfg)
 {
-    const QString type = cfg.inherits + "::Item" + itemType(e->type);
+    if (e->name.isEmpty()) {
+        return QString{};
+    }
+
+    const QString type = cfg.inherits + QLatin1String{"::Item"} + itemType(e->type);
 
     QString fCap = e->name;
-    fCap[0] = fCap[0].toUpper();
+    fCap[0] = fCap.at(0).toUpper();
     const QString argSuffix = (!e->param.isEmpty()) ? (QStringLiteral("[%1]").arg(e->paramMax + 1)) : QString();
     QString result;
 
     if (!cfg.itemAccessors && !cfg.dpointer) {
-        result += "  " + (!e->signalList.isEmpty() ? QStringLiteral("KConfigCompilerSignallingItem") : type) +
-            "  *item" + fCap + argSuffix + ";\n";
+        result += QLatin1String{"  "} + (!e->signalList.isEmpty() ? QStringLiteral("KConfigCompilerSignallingItem") : type);
+        result += QLatin1String("  *item%1;\n").arg(fCap + argSuffix);
     }
 
     if (!e->signalList.isEmpty()) {
-        result += "  " + type + "  *" + innerItemVar(e, cfg) + argSuffix + ";\n";
+        result += QLatin1String("  %1  *%2;\n").arg(type, innerItemVar(e, cfg) + argSuffix);
     }
 
     return result;
@@ -421,15 +402,15 @@ QString itemVar(const CfgEntry *e, const KConfigParameters &cfg)
     QString result;
     if (cfg.itemAccessors) {
         if (!cfg.dpointer) {
-            result = 'm' + e->name + "Item";
-            result[1] = result[1].toUpper();
+            result = QLatin1String("m%1Item").arg(e->name);
+            result[1] = result.at(1).toUpper();
         } else {
-            result = e->name + "Item";
-            result[0] = result[0].toLower();
+            result = e->name + QLatin1String{"Item"};
+            result[0] = result.at(0).toLower();
         }
     } else {
-        result = "item" + e->name;
-        result[4] = result[4].toUpper();
+        result = QLatin1String{"item"} + e->name;
+        result[4] = result.at(4).toUpper();
     }
     return result;
 }
@@ -441,72 +422,62 @@ QString innerItemVar(const CfgEntry *e, const KConfigParameters &cfg)
 {
     if (e->signalList.isEmpty()) {
         return itemPath(e, cfg);
-    } else {
-        QString result = "innerItem" + e->name;
-        result[9] = result[9].toUpper();
-        return result;
     }
+
+    QString result = QLatin1String{"innerItem"} + e->name;
+    result[9] = result.at(9).toUpper();
+    return result;
 }
 
 QString itemPath(const CfgEntry *e, const KConfigParameters &cfg)
 {
-    QString result;
-    if (cfg.dpointer) {
-        result = "d->" + itemVar(e, cfg);
-    } else {
-        result = itemVar(e, cfg);
-    }
-    return result;
+    return cfg.dpointer ? QLatin1String{"d->"} + itemVar(e, cfg) : itemVar(e, cfg);
 }
 
-QString newInnerItem(const CfgEntry *entry, const QString &key, const QString &defaultValue,
-                const KConfigParameters &cfg, const QString &param) {
-    QString t = "new "+ cfg.inherits + "::Item" + itemType(entry->type) + "( currentGroup(), "
-            + key + ", " + varPath( entry->name, cfg ) + param;
+QString newInnerItem(const CfgEntry *entry, const QString &key, const QString &defaultValue, const KConfigParameters &cfg, const QString &param)
+{
+    QString str = QLatin1String("new %1::Item%2").arg(cfg.inherits, itemType(entry->type));
+    str += QLatin1String("( currentGroup(), %1, %2").arg(key, varPath(entry->name, cfg) + param);
 
     if (entry->type == QLatin1String("Enum")) {
-        t += ", values" + entry->name;
+        str += QLatin1String{", values"} + entry->name;
     }
     if (!defaultValue.isEmpty()) {
-        t += QLatin1String(", ") + defaultValue;
+        str += QLatin1String(", ") + defaultValue;
     }
-    t += QLatin1String(" );");
+    str += QLatin1String(" );");
 
-    return t;
+    return str;
 }
 
-QString newItem(const CfgEntry *entry, const QString &key, const QString &defaultValue,
-                const KConfigParameters &cfg, const QString &param) {
-
-    QList<Signal> sigs = entry->signalList;
-    QString t;
-    if (!sigs.isEmpty()) {
-        t += QLatin1String("new KConfigCompilerSignallingItem(") + innerItemVar(entry, cfg) + param;
-        t += QLatin1String(", this, notifyFunction, ");
-        //append the signal flags
-        for (int i = 0; i < sigs.size(); ++i) {
-            if (i != 0)
-                t += QLatin1String(" | ");
-            t += signalEnumName(sigs[i].name);
-        }
-        t += QLatin1String(");");
-    } else {
-        t += newInnerItem(entry, key, defaultValue, cfg, param);
+QString newItem(const CfgEntry *entry, const QString &key, const QString &defaultValue, const KConfigParameters &cfg, const QString &param)
+{
+    const QList<Signal> sigs = entry->signalList;
+    if (sigs.isEmpty()) {
+        return newInnerItem(entry, key, defaultValue, cfg, param);
     }
-    return t;
+
+    QString str;
+    str += QLatin1String("new KConfigCompilerSignallingItem(%1, this, notifyFunction, ").arg(innerItemVar(entry, cfg) + param);
+    // Append the signal flags
+    const int listSize = sigs.size();
+    for (int i = 0; i < listSize; ++i) {
+        if (i != 0) {
+            str += QLatin1String(" | ");
+        }
+        str += signalEnumName(sigs[i].name);
+    }
+    str += QLatin1String(");");
+
+    return str;
 }
 
 QString paramString(const QString &s, const CfgEntry *e, int i)
 {
     QString result = s;
-    QString needle = "$(" + e->param + ')';
+    const QString needle = QLatin1String("$(%1)").arg(e->param);
     if (result.contains(needle)) {
-        QString tmp;
-        if (e->paramType == QLatin1String("Enum")) {
-            tmp = e->paramValues.at(i);
-        } else {
-            tmp = QString::number(i);
-        }
+        const QString tmp = e->paramType == QLatin1String{"Enum"} ? e->paramValues.at(i) : QString::number(i);
 
         result.replace(needle, tmp);
     }
@@ -518,19 +489,34 @@ QString paramString(const QString &group, const QList<Param> &parameters)
     QString paramString = group;
     QString arguments;
     int i = 1;
-    for (QList<Param>::ConstIterator it = parameters.constBegin();
-            it != parameters.constEnd(); ++it) {
-        if (paramString.contains("$(" + (*it).name + ')')) {
+    bool firstArg = true;
+    for (const auto &param : parameters) {
+        const QString paramName = param.name;
+        const QString str = QLatin1String("$(%1)").arg(paramName);
+        if (paramString.contains(str)) {
             const QString tmp = QStringLiteral("%%1").arg(i++);
-            paramString.replace("$(" + (*it).name + ')', tmp);
-            arguments += ".arg( mParam" + (*it).name + " )";
+            paramString.replace(str, tmp);
+
+            if (firstArg) {
+                arguments += QLatin1String{".arg( "};
+                firstArg = false;
+            }
+
+            arguments += QLatin1String("mParam%1, ").arg(paramName);
         }
     }
-    if (arguments.isEmpty()) {
-        return "QStringLiteral( \"" + group + "\" )";
+
+    if (!arguments.isEmpty()) {
+        // Remove the last ", "
+        arguments.chop(2);
+
+        // Close the ".arg( "
+        arguments += QLatin1String{" )"};
+    } else {
+        return QLatin1String("QStringLiteral( \"%1\" )").arg(group);
     }
 
-    return "QStringLiteral( \"" + paramString + "\" )" + arguments;
+    return QLatin1String("QStringLiteral( \"%1\" )%2").arg(paramString, arguments);
 }
 
 QString translatedString(const KConfigParameters &cfg, const QString &string, const QString &context, const QString &param, const QString &paramValue)
@@ -540,35 +526,35 @@ QString translatedString(const KConfigParameters &cfg, const QString &string, co
     switch (cfg.translationSystem) {
     case KConfigParameters::QtTranslation:
         if (!context.isEmpty()) {
-            result += "/*: " + context + " */ QCoreApplication::translate(\"";
+            result += QLatin1String("/*: %1 */ QCoreApplication::translate(\"").arg(context);
         } else {
-            result += QLatin1String("QCoreApplication::translate(\"");
+            result += QLatin1String{"QCoreApplication::translate(\""};
         }
-        result += cfg.className + "\", ";
+        result += QLatin1String("%1\", ").arg(cfg.className);
         break;
 
     case KConfigParameters::KdeTranslation:
         if (!cfg.translationDomain.isEmpty() && !context.isEmpty()) {
-            result += "i18ndc(" + quoteString(cfg.translationDomain) + ", " + quoteString(context) + ", ";
+            result += QLatin1String("i18ndc(%1, %2, ").arg(quoteString(cfg.translationDomain), quoteString(context));
         } else if (!cfg.translationDomain.isEmpty()) {
-            result += "i18nd(" + quoteString(cfg.translationDomain) + ", ";
+            result += QLatin1String("i18nd(%1, ").arg(quoteString(cfg.translationDomain));
         } else if (!context.isEmpty()) {
-            result += "i18nc(" + quoteString(context) + ", ";
+            result += QLatin1String("i18nc(%1, ").arg(quoteString(context));
         } else {
-            result += QLatin1String("i18n(");
+            result += QLatin1String{"i18n("};
         }
         break;
     }
 
     if (!param.isEmpty()) {
         QString resolvedString = string;
-        resolvedString.replace("$(" + param + ')', paramValue);
+        resolvedString.replace(QLatin1String("$(%1)").arg(param), paramValue);
         result += quoteString(resolvedString);
     } else {
         result += quoteString(string);
     }
 
-    result += ')';
+    result += QLatin1Char{')'};
 
     return result;
 }
@@ -581,38 +567,30 @@ QString userTextsFunctions(const CfgEntry *e, const KConfigParameters &cfg, QStr
         itemVarStr = itemPath(e, cfg);
     }
     if (!e->label.isEmpty()) {
-        txt += "  " + itemVarStr + "->setLabel( ";
-        txt += translatedString(cfg, e->label, e->labelContext, e->param, i);
-        txt += QLatin1String(" );\n");
+        txt += QLatin1String("  %1->setLabel( %2 );\n").arg(itemVarStr, translatedString(cfg, e->label, e->labelContext, e->param, i));
     }
     if (!e->toolTip.isEmpty()) {
-        txt += "  " + itemVarStr + "->setToolTip( ";
-        txt += translatedString(cfg, e->toolTip, e->toolTipContext, e->param, i);
-        txt += QLatin1String(" );\n");
+        txt += QLatin1String("  %1->setToolTip( %2 );\n").arg(itemVarStr, translatedString(cfg, e->toolTip, e->toolTipContext, e->param, i));
     }
     if (!e->whatsThis.isEmpty()) {
-        txt += "  " + itemVarStr + "->setWhatsThis( ";
-        txt += translatedString(cfg, e->whatsThis, e->whatsThisContext, e->param, i);
-        txt += QLatin1String(" );\n");
+        txt += QLatin1String("  %1->setWhatsThis( %2 );\n").arg(itemVarStr, translatedString(cfg, e->whatsThis, e->whatsThisContext, e->param, i));
     }
     return txt;
 }
 
-
 // returns the member mutator implementation
 // which should go in the h file if inline
 // or the cpp file if not inline
-//TODO: Fix add Debug Method, it should also take the debug string.
+// TODO: Fix add Debug Method, it should also take the debug string.
 void addDebugMethod(QTextStream &out, const KConfigParameters &cfg, const QString &n)
 {
     if (cfg.qCategoryLoggingName.isEmpty()) {
-       out << "  qDebug() << \"" << setFunction(n);
+        out << "  qDebug() << \"" << setFunction(n);
     } else {
-       out << "  qCDebug(" << cfg.qCategoryLoggingName << ") << \"" << setFunction(n);
+        out << "  qCDebug(" << cfg.qCategoryLoggingName << ") << \"" << setFunction(n);
     }
 }
 
-
 // returns the member get default implementation
 // which should go in the h file if inline
 // or the cpp file if not inline
@@ -632,7 +610,7 @@ QString memberGetDefaultBody(const CfgEntry *e)
         QString defaultValue = e->defaultValue;
 
         out << "  default:\n";
-        out << "    return " << defaultValue.replace("$(" + e->param + ')', QLatin1String("i")) << ";\n";
+        out << "    return " << defaultValue.replace(QLatin1String("$(%1)").arg(e->param), QLatin1String("i")) << ";\n";
         out << "  }\n";
     } else {
         out << "  return " << e->defaultValue << ';';
@@ -641,7 +619,7 @@ QString memberGetDefaultBody(const CfgEntry *e)
     return result;
 }
 
-// returns the item accesor implementation
+// returns the item accessor implementation
 // which should go in the h file if inline
 // or the cpp file if not inline
 QString itemAccessorBody(const CfgEntry *e, const KConfigParameters &cfg)
@@ -658,7 +636,7 @@ QString itemAccessorBody(const CfgEntry *e, const KConfigParameters &cfg)
     return result;
 }
 
-//indents text adding X spaces per line
+// indents text adding X spaces per line
 QString indent(QString text, int spaces)
 {
     QString result;
@@ -667,17 +645,20 @@ QString indent(QString text, int spaces)
     QString currLine;
     while (!in.atEnd()) {
         currLine = in.readLine();
-        if (!currLine.isEmpty())
-            for (int i = 0; i < spaces; i++) {
+        if (!currLine.isEmpty()) {
+            for (int i = 0; i < spaces; ++i) {
                 out << " ";
             }
+        }
         out << currLine << '\n';
     }
     return result;
 }
 
-bool hasErrors(KConfigXmlParser &parser, const ParseResult& parseResult, const KConfigParameters &cfg)
+bool hasErrors(KConfigXmlParser &parser, const ParseResult &parseResult, const KConfigParameters &cfg)
 {
+    Q_UNUSED(parser)
+
     if (cfg.className.isEmpty()) {
         std::cerr << "Class name missing" << std::endl;
         return true;
@@ -694,18 +675,18 @@ bool hasErrors(KConfigXmlParser &parser, const ParseResult& parseResult, const K
     }
 
     /* TODO: For some reason some configuration files prefer to have *no* entries
-    * at all in it, and the generated code is mostly bogus as KConfigXT will not
-    * handle save / load / properties, etc, nothing.
-    *
-    * The first of those files that I came across are qmakebuilderconfig.kcfg from the KDevelop
-    * project.
-    * I think we should remove the possibility of creating configuration classes from configuration
-    * files that don't really have configuration in it. but I'm changing this right now to allow
-    * kdevelop files to pass.
-    *
-    * Remove for KDE 6
-    * (to make things more interesting, it failed in a code that's never used within KDevelop... )
-    */
+     * at all in it, and the generated code is mostly bogus as KConfigXT will not
+     * handle save / load / properties, etc, nothing.
+     *
+     * The first of those files that I came across are qmakebuilderconfig.kcfg from the KDevelop
+     * project.
+     * I think we should remove the possibility of creating configuration classes from configuration
+     * files that don't really have configuration in it. but I'm changing this right now to allow
+     * kdevelop files to pass.
+     *
+     * Remove for KDE 6
+     * (to make things more interesting, it failed in a code that's never used within KDevelop... )
+     */
     if (parseResult.entries.isEmpty()) {
         std::cerr << "No entries." << std::endl;
         return false;
@@ -720,15 +701,16 @@ int main(int argc, char **argv)
     app.setApplicationName(QStringLiteral("kconfig_compiler"));
     app.setApplicationVersion(QStringLiteral(KCONFIG_VERSION_STRING));
 
-    QString inputFilename, codegenFilename;
+    QString inputFilename;
+    QString codegenFilename;
 
-    QCommandLineOption targetDirectoryOption(QStringList { QStringLiteral("d"), QStringLiteral("directory") },
-            QCoreApplication::translate("main", "Directory to generate files in [.]"),
-            QCoreApplication::translate("main", "directory"), QStringLiteral("."));
+    QCommandLineOption targetDirectoryOption(QStringList{QStringLiteral("d"), QStringLiteral("directory")},
+                                             QCoreApplication::translate("main", "Directory to generate files in [.]"),
+                                             QCoreApplication::translate("main", "directory"),
+                                             QStringLiteral("."));
 
-    QCommandLineOption licenseOption (
-        QStringList { QStringLiteral("l"), QStringLiteral("license") },
-        QCoreApplication::translate("main", "Display software license."));
+    QCommandLineOption licenseOption(QStringList{QStringLiteral("l"), QStringLiteral("license")},
+                                     QCoreApplication::translate("main", "Display software license."));
 
     QCommandLineParser parser;
 
@@ -736,7 +718,7 @@ int main(int argc, char **argv)
     parser.addPositionalArgument(QStringLiteral("file.kcfgc"), QStringLiteral("Code generation options file"));
 
     parser.addOption(targetDirectoryOption);
-    parser.addOption (licenseOption);
+    parser.addOption(licenseOption);
 
     parser.addVersionOption();
     parser.addHelpOption();
@@ -755,7 +737,7 @@ int main(int argc, char **argv)
     const QStringList args = parser.positionalArguments();
     if (args.count() < 2) {
         std::cerr << "Too few arguments." << std::endl;
-	    return 1;
+        return 1;
     }
 
     if (args.count() > 2) {
@@ -769,16 +751,17 @@ int main(int argc, char **argv)
     QString baseDir = parser.value(targetDirectoryOption);
 
 #ifdef Q_OS_WIN
-    if (!baseDir.endsWith('/') && !baseDir.endsWith('\\'))
+    if (!baseDir.endsWith(QLatin1Char{'/'}) && !baseDir.endsWith(QLatin1Char{'\\'})) {
 #else
-    if (!baseDir.endsWith('/'))
+    if (!baseDir.endsWith(QLatin1Char{'/'})) {
 #endif
-        baseDir.append("/");
+        baseDir.append(QLatin1Char{'/'});
+    }
 
     KConfigParameters cfg(codegenFilename);
 
     KConfigXmlParser xmlParser(cfg, inputFilename);
-    
+
     // The Xml Parser aborts in the case of an error, so if we get
     // to parseResult, we have a working Xml file.
     xmlParser.start();
@@ -790,12 +773,12 @@ int main(int argc, char **argv)
     }
 
     // TODO: Move this to somewhere saner.
-    for (const auto &signal : qAsConst(parseResult.signalList)) {
+    for (const auto &signal : std::as_const(parseResult.signalList)) {
         parseResult.hasNonModifySignals |= !signal.modify;
     }
 
     // remove '.kcfg' from the name.
-    const QString baseName = inputFilename.mid(0, inputFilename.size()-5);
+    const QString baseName = inputFilename.mid(0, inputFilename.size() - 5);
     KConfigHeaderGenerator headerGenerator(baseName, baseDir, cfg, parseResult);
     headerGenerator.start();
     headerGenerator.save();
